## Packages

library(tidyverse)
library(readxl)
library(lme4)
library(lmerTest)
library(emmeans)
library(rstatix)
library(ggfortify)
library(patchwork)
library(grid)
library(RCurl)
library(ggview)
library(performance)

### Importing the data for the 3 Mantis species

################################################################################
## Hagiomantis sp. - white morphotype
################################################################################

data_hagi<-
  read_excel("data_contrasts.xlsx",sheet=1,range="A1:E37")%>%
  mutate(background=factor(background,
                           levels=c("greenish_brown","whitish","lichen")),
         scale=factor(scale,
                      levels=c("local","micro")))

# Running mixed-effects model to test the camouflage of the white morphospecies
# against tree trunk types

################################################################################
# COLOUR JNDs

# Creating the model

model_hagi_chromatic<-
  lmer(log(jnd_chromatic)~background+(1|ID),
       data=data_hagi)

# Testing assumptions

check_model(model_hagi_chromatic)

qqnorm(residuals(model_hagi_chromatic))
qqline(residuals(model_hagi_chromatic))

data_hagi%>%
  levene_test(log(jnd_chromatic)~background)

# Testing the signficance of factors

anova(model_hagi_chromatic)  
summary(model_hagi_chromatic)

# Performing post-hoc tests

pairs(emmeans(model_hagi_chromatic,"background"))

data_hagi%>%
  group_by(background)%>%
  summarise(mean_colour_jnd=mean(jnd_chromatic),
            sd_colour_jnd=sd(jnd_chromatic),
            sample_size=n())%>%
  mutate(se_colour_jnd=sd_colour_jnd/sqrt(sample_size))


################################################################################
# LUMINANCE JNDs

# Creating the model

model_hagi_achromatic<-
  lmer(jnd_lum~background+(1|ID),
       data=data_hagi)

# Testing assumptions

check_model(model_hagi_achromatic)

qqnorm(residuals(model_hagi_achromatic))
qqline(residuals(model_hagi_achromatic))

data_hagi%>%
  levene_test(jnd_lum~background)

# Testing the significance of factors

anova(model_hagi_achromatic)  
summary(model_hagi_achromatic)

# Performing post-hoc tests

pairs(emmeans(model_hagi_achromatic,"background"))

################################################################################
## Liturgusa  - Green morphotype
################################################################################

data_lit1<-
  read_excel("data_contrasts.xlsx",sheet=2,range="A1:E31")%>%
  mutate(background=factor(background,
                           levels=c("greenish_brown","whitish","bryophyte")),
         scale=factor(scale,
                      levels=c("local","micro")))

data_lit1%>%
  group_by(background)%>%
  summarise(mean_colour_jnd=mean(jnd_chromatic),
            sd_colour_jnd=sd(jnd_chromatic),
            sample_size=n())%>%
  mutate(se_colour_jnd=sd_colour_jnd/sqrt(sample_size))

data_lit1%>%
  group_by(background)%>%
  summarise(mean_lum_jnd=mean(jnd_lum),
            sd_lum_jnd=sd(jnd_lum),
            sample_size=n())%>%
  mutate(se_lum_jnd=sd_lum_jnd/sqrt(sample_size))

# Running mixed-effects model to test the camouflage of the green morphospecies
# against tree trunk types

################################################################################
# COLOUR JNDs

# Creating the model

model_lit1_chromatic<-
  lmer(log(jnd_chromatic)~background+(1|ID),
       data=data_lit1)

# Testing assumptions

check_model(model_lit1_chromatic)

qqnorm(residuals(model_lit1_chromatic))
qqline(residuals(model_lit1_chromatic))

data_lit1%>%
  levene_test(log(jnd_chromatic)~background)

# Testing the significance of factors

anova(model_lit1_chromatic)  
summary(model_lit1_chromatic)

# Performing post-hoc tests

pairs(emmeans(model_lit1_chromatic,"background"))

################################################################################
# LUMINANCE JNDs

# Creating the model

model_lit1_achromatic<-
  lmer(log(jnd_lum)~background+(1|ID),
       data=data_lit1)

# Testing assumptions

check_model(model_lit1_achromatic)

qqnorm(residuals(model_lit1_achromatic))
qqline(residuals(model_lit1_achromatic))

data_lit1%>%
  levene_test(log(jnd_lum)~background)

# Testing the significance of factors

anova(model_lit1_achromatic)  
summary(model_lit1_achromatic)

# Performing post-hoc tests

pairs(emmeans(model_lit1_achromatic,"background"))

################################################################################
## Liturgusidae  - grey morphotype
################################################################################

data_lit2<-
  read_excel("data_contrasts.xlsx",sheet=3,range="A1:E16")%>%
  mutate(background=factor(background,
                           levels=c("greenish_brown","whitish","lichen")),
         scale=factor(scale,
                      levels=c("local","micro")))

data_lit2%>%
  group_by(background)%>%
  summarise(mean_colour_jnd=mean(jnd_chromatic),
            sd_colour_jnd=sd(jnd_chromatic),
            sample_size=n())%>%
  mutate(se_colour_jnd=sd_colour_jnd/sqrt(sample_size))

# Running mixed-effects model to test the camouflage of the grey morphospecies
# against tree trunk types

################################################################################
# COLOUR JNDs

# Creating the model

model_lit2_chromatic<-
  lmer(log(jnd_chromatic)~background+(1|ID),
       data=data_lit2)

# Testing assumptions

check_model(model_lit2_chromatic)

qqnorm(residuals(model_lit2_chromatic))
qqline(residuals(model_lit2_chromatic))

data_lit2%>%
  levene_test(log(jnd_chromatic)~background)

# Testing the signficance of factors

anova(model_lit2_chromatic)  
summary(model_lit2_chromatic)

# Performing post-hoc tests

pairs(emmeans(model_lit2_chromatic,"background"))

################################################################################
# LUMINANCE JNDs

# Creating the model

model_lit2_achromatic<-
  lmer(log(jnd_lum)~background+(1|ID),
       data=data_lit2)

# Testing assumptions

check_model(model_lit2_achromatic)

# Testing the signficance of factors

anova(model_lit2_achromatic)  
summary(model_lit2_achromatic)
           
################################################################################
## GENERATING THE FIGURES 
################################################################################

################################################################################
### Data manipulation
################################################################################

data_hagi_2<-
  data_hagi%>%
  pivot_longer(c("jnd_chromatic","jnd_lum"),
                 names_to="contrast_type",values_to="jnd")%>%
  mutate(contrast_type=factor(contrast_type),
         species=factor(rep("hagi",72)))

data_hagi_2$contrast_type<-
  fct_recode(data_hagi_2$contrast_type,
             colour="jnd_chromatic",
             luminance="jnd_lum")

data_lit1_2<-
  data_lit1%>%
  pivot_longer(c("jnd_chromatic","jnd_lum"),
               names_to="contrast_type",values_to="jnd")%>%
  mutate(contrast_type=factor(contrast_type),
         species=factor(rep("lit1",60)))

data_lit1_2$contrast_type<-
  fct_recode(data_lit1_2$contrast_type,
             colour="jnd_chromatic",
             luminance="jnd_lum")

data_lit2_2<-
  data_lit2%>%
  pivot_longer(c("jnd_chromatic","jnd_lum"),
               names_to="contrast_type",values_to="jnd")%>%
  mutate(contrast_type=factor(contrast_type),
         species=factor(rep("lit2",30)))

data_lit2_2$contrast_type<-
  fct_recode(data_lit2_2$contrast_type,
             colour="jnd_chromatic",
             luminance="jnd_lum")

data_mantis<-
  bind_rows(data_hagi_2,
            data_lit1_2,
            data_lit2_2)

################################################################################
## Generating all graphics
################################################################################

contrast_labs<-c("Colour","Luminance")
names(contrast_labs)<-c("colour","luminance")

## Hagiomantis - White morph 

graph_hagi_a<-
  ggplot(data=data_mantis%>%
              filter(species=="hagi"))+
  geom_boxplot(aes(x=background,y=jnd,fill=background,linetype=scale),
               linewidth=0.5,alpha=0.25,outlier.shape=NA,
               show.legend=FALSE)+
  geom_jitter(aes(x=background,y=jnd,fill=background),
              position=position_jitterdodge(),size=2.5,shape=21,
              show.legend=FALSE)+
  facet_grid(~contrast_type,
             labeller=labeller(contrast_type=contrast_labs))

graph_hagi_b<-
  graph_hagi_a+
  scale_x_discrete(name="Background",
                   labels=c("Greenish-brown","Whitish","Lichen"))+
  scale_y_continuous(name="JNDs",
                     breaks=c(0,2.5,5,7.5,10,12.5,15,17.5,20,22.5),
                     limits=c(0,23))+
  scale_fill_manual(values=c("#33FF00","#FFFFFF","#666666"))+
  scale_linetype_manual(values=c("solid","dashed"))

graph_hagi_c<-
  graph_hagi_b+
  theme_bw()+
  theme(axis.text.x=element_text(colour="black",size=10,hjust=0.5),
        axis.text.y=element_text(colour="black",size=10),
        axis.title.x=element_text(face="bold", colour="black", 
                                  size=12,margin=margin(
                                  t=10,r=20,b=10,l=20)),
        axis.title.y=element_text(face="bold",colour="black", 
                                  size=12,margin=margin(
                                  t=10,r=10,b=10,l=10)),
        legend.position="none", 
        panel.background=element_rect(fill="white"),
        panel.border=element_rect(linewidth=1,linetype="solid",
                                  colour="black"),
        panel.grid.major=element_blank(),
        panel.grid.minor=element_blank(),
        strip.text.x=element_text(size=12,face="bold"),
        strip.background=element_rect(colour="black"),
        panel.spacing=unit(0.5,"cm"))

text_hagi_species<-
  data.frame(label=c("White mantis"),
             contrast_type=as.factor("colour"),
             x=1.1,y=21.5)

text_hagi_stats<-
  data.frame(label=c("a","b","c","a","ab","ac"),
             contrast_type=as.factor(
               c(rep("colour",3),rep("luminance",3))),
             x=c(1,2,3,1,2,3),y=c(9.5,5.5,7.5,20.5,21.5,23))    
    
graph_hagi_d<-
  graph_hagi_c+ 
  geom_text(data=text_hagi_species,
          aes(x=x,y=y,label=label),
          size=3.5)+
  geom_text(data=text_hagi_stats,
            aes(x=x,y=y,label=label),
            fontface="bold",size=3)   
    
## Litugursidae - Grey morph 

graph_lit2_a<-
  ggplot(data=data_mantis%>%
         filter(species=="lit2"))+
  geom_boxplot(aes(x=background,y=jnd,fill=background,linetype=scale),
               linewidth=0.5,alpha=0.25,outlier.shape=NA,
               show.legend=FALSE)+
  geom_jitter(aes(x=background,y=jnd,fill=background),
              position=position_jitterdodge(),size=2.5,shape=21,
              show.legend=FALSE)+
  facet_grid(~contrast_type,
             labeller=labeller(contrast_type=contrast_labs))

graph_lit2_b<-
  graph_lit2_a+
  scale_x_discrete(name="Background",
                   labels=c("Greenish-brown","Whitish","Lichen"))+
  scale_y_continuous(name="JNDs",
                     breaks=c(0,2.5,5,7.5,10,12.5,15,17.5,20,22.5),
                     limits=c(0,23))+
  scale_fill_manual(values=c("#33FF00","#FFFFFF","#666666"))+
  scale_linetype_manual(values=c("solid","dashed"))

graph_lit2_c<-
  graph_lit2_b+
  theme_bw()+
  theme(axis.text.x=element_text(colour="black",size=10,hjust=0.5),
        axis.text.y=element_text(colour="black",size=10),
        axis.title.x=element_text(face="bold", colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=20,b=10,l=20)),
        axis.title.y=element_text(face="bold",colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=10,b=10,l=10)),
        legend.position="none", 
        panel.background=element_rect(fill="white"),
        panel.border=element_rect(linewidth=1,linetype="solid",
                                  colour="black"),
        panel.grid.major=element_blank(),
        panel.grid.minor=element_blank(),
        strip.text.x=element_text(size=12,face="bold"),
        strip.background=element_rect(colour="black"),
        panel.spacing=unit(0.5,"cm"))

text_lit2_species<-
  data.frame(label=c("Grey mantis"),
             contrast_type=as.factor("colour"),
             x=1.1,y=21.5)

text_lit2_stats<-
  data.frame(label=c("a","b","ab"),
             contrast_type=as.factor(rep("colour",3)),
             x=c(1,2,3),y=c(7,5,7))    

graph_lit2_d<-
  graph_lit2_c+ 
  geom_text(data=text_lit2_species,
            aes(x=x,y=y,label=label),
            size=3.5)+
  geom_text(data=text_lit2_stats,
            aes(x=x,y=y,label=label),
            fontface="bold",size=3)   

## Liturgusa - Green morph 

graph_lit1_a<-
  ggplot(data=data_mantis%>%
         filter(species=="lit1"))+
  geom_boxplot(aes(x=background,y=jnd,fill=background,linetype=scale),
               linewidth=0.5,alpha=0.25,outlier.shape=NA,
               show.legend=FALSE)+
  geom_jitter(aes(x=background,y=jnd,fill=background),
              position=position_jitterdodge(),size=2.5,shape=21,
              show.legend=FALSE)+
  facet_grid(~contrast_type,
             labeller=labeller(contrast_type=contrast_labs))

graph_lit1_b<-
  graph_lit1_a+
  scale_x_discrete(name="Background",
                   labels=c("Greenish-brown","Whitish","Bryophyte"))+
  scale_y_continuous(name="JNDs",
                     breaks=c(0,5,10,15,20,25,30,35,40,45),
                     limits=c(0,46))+
  scale_fill_manual(values=c("#33FF00","#FFFFFF","#666666"))+
  scale_linetype_manual(values=c("solid","dashed"))

graph_lit1_c<-
  graph_lit1_b+
  theme_bw()+
  theme(axis.text.x=element_text(colour="black",size=10,hjust=0.5),
        axis.text.y=element_text(colour="black",size=10),
        axis.title.x=element_text(face="bold", colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=20,b=10,l=20)),
        axis.title.y=element_text(face="bold",colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=10,b=10,l=10)),
        legend.position="none", 
        panel.background=element_rect(fill="white"),
        panel.border=element_rect(linewidth=1,linetype="solid",
                                  colour="black"),
        panel.grid.major=element_blank(),
        panel.grid.minor=element_blank(),
        strip.text.x=element_text(size=12,face="bold"),
        strip.background=element_rect(colour="black"),
        panel.spacing=unit(0.5,"cm"))

text_lit1_species<-
  data.frame(label=c("Green mantis"),
             contrast_type=as.factor("colour"),
             x=1.1,y=44)

text_lit1_stats<-
  data.frame(label=c("a","a","b","a","a","b"),
             contrast_type=
             as.factor(c(rep("colour",3),rep("luminance",3))),
             x=c(1,2,3,1,2,3),y=c(20.5,15.5,6.5,42,42,15))    

graph_lit1_d<-
  graph_lit1_c+ 
  geom_text(data=text_lit1_species,
            aes(x=x,y=y,label=label),
            size=3.5)+
  geom_text(data=text_lit1_stats,
            aes(x=x,y=y,label=label),
            fontface="bold",size=3) 

################################################################################
### Combining all plots

final_figure_contrasts<-
  graph_hagi_d+
  graph_lit2_d+
  graph_lit1_d+
  plot_layout(ncol=1)

# Remove title and text for plot 1 and facets for plot 2 and plot 3

final_figure_contrasts[[1]]<-
  final_figure_contrasts[[1]]+
  theme(plot.margin=margin(0.5,0.5,0,0.5,"cm"),
        axis.title.x=element_blank(),
        axis.text.x=element_blank())

final_figure_contrasts[[2]]<-
  final_figure_contrasts[[2]]+
  theme(plot.margin=margin(0.5,0.5,0,0.5,"cm"),
        axis.title.x=element_blank(),
        strip.text.x=element_blank(),
        strip.background=element_blank())

final_figure_contrasts[[3]]<-
  final_figure_contrasts[[3]]+
  theme(plot.margin=margin(0.5,0.5,0.5,0.5,"cm"),
        strip.text.x=element_blank(),
        strip.background=element_blank())

ggsave("Figure 3.png",final_figure_contrasts,
       height=27.5,width=20,units="cm",dpi=600)
