## Packages

library(tidyverse)
library(readxl)
library(lme4)
library(lmerTest)
library(emmeans)
library(rstatix)
library(ggfortify)
library(patchwork)
library(grid)
library(RCurl)
library(ggview)

### Importing the data for the 3 Mantises species

################################################################################
## Hagiomantis - White morphotype
################################################################################

data_hagi_gabrat<-
  read_excel("GabRat_results.xlsx",sheet=1,range="A1:C25")%>%
  mutate(background=factor(background))

# Running mixed-effects model to test the Disruptive coloration of the Hagiomantis on withish and greeninsh tree trunks 

# Creating the model

model_hagi_gabrat<-
  lmer(log(gabrat)~background+(1|ID),
       data=data_hagi_gabrat)

# Testing the signficance of factors

check_model(model_hagi_gabrat)

anova(model_hagi_gabrat) 
summary(model_hagi_gabrat)

## Calculating some parammeters 

my_sum<-
  data_hagi_gabrat%>%
  group_by(background) %>%
  summarise(n=n(),
            mean=mean(gabrat),
            sd=sd(gabrat))%>%
  mutate(se=sd/sqrt(n),
         ic=se*qt((1-0.05)/2 + .5, n-1))

################################################################################
## Liturgusa - Green morphotype
################################################################################

data_lit1_gabrat<-
  read_excel("GabRat_results.xlsx",sheet=2,range="A1:C21")%>%
  mutate(background=factor(background))

################################################################################

# Creating the model

model_liturgusa_gabrat<-
lmer(log(gabrat)~background+(1|ID),
     data=data_lit1_gabrat)

check_model(model_liturgusa_gabrat)

# Testing the significance of factors

anova(model_liturgusa_gabrat)
summary(model_liturgusa_gabrat)

# Performing post-hoc tests

data_lit1_gabrat%>%
  group_by(background)%>%
  summarise(n=n(),
            mean=mean(gabrat),
            sd=sd(gabrat))%>%
  mutate(se=sd/sqrt(n),
         ic=se*qt((1-0.05)/2+ .5,n-1))

################################################################################
## Liturgusidae sp.2  - grey morphotype
################################################################################

data_lit2_gabrat<-
  read_excel("GabRat_results.xlsx",sheet=3,range="A1:c11")%>%
  mutate(background=factor(background))
  
################################################################################

# Creating the model

model_liturgusa2_gabrat<-
  lmer(gabrat~background+(1|ID),
       data=data_lit2_gabrat)

check_model(model_liturgusa2_gabrat)

# Testing the significance of factors

anova(model_liturgusa2_gabrat)
summary(model_liturgusa2_gabrat)


data_lit2_gabrat%>%
  group_by(background)%>%
  summarise(n=n(),
            mean=mean(gabrat),
            sd=sd(gabrat))%>%
  mutate(se=sd/sqrt(n),
         ic=se*qt((1-0.05)/2 + .5, n-1))

##########################################################################
## GENERATING THE FIGURES
##########################################################################

#################################################################################
### Data manipulation
################################################################################

data_gabrat<-
  bind_rows(
    data_hagi_gabrat,
    data_lit1_gabrat,
    data_lit2_gabrat)%>%
  mutate(species=c(rep("hagi",24),rep("lit1",20),rep("lit2",10)))%>%
  mutate(species=factor(species))

################################################################################
## Generating all graphics
################################################################################

## Hagiomantis - White morph 

graph_hagi_gabrat_a<-
  ggplot(data=data_gabrat%>%
         filter(species=="hagi"))+
  geom_boxplot(aes(x=background,y=gabrat,fill=background),
               linewidth=0.5,alpha=0.25,outlier.shape=NA,
               show.legend=FALSE)+
  geom_jitter(aes(x=background,y=gabrat,fill=background),
              position=position_jitterdodge(),size=2.5,shape=21,
              show.legend=FALSE)

graph_hagi_gabrat_b<-
  graph_hagi_gabrat_a+
  scale_x_discrete(name="Background",
                   labels=c("Greenish-brown","Whitish"))+
  scale_y_continuous(name="GabRat",
                     breaks=c(0.05,0.1,0.15,0.2,0.25,0.3,0.35,0.4),
                     limits=c(0.05,0.4))+
  scale_fill_manual(values=c("#33FF00","#FFFFFF"))

graph_hagi_gabrat_c<-
  graph_hagi_gabrat_b+
  theme_bw()+
  theme(axis.text.x=element_text(colour="black",size=10,hjust=0.5),
        axis.text.y=element_text(colour="black",size=10),
        axis.title.x=element_text(face="bold", colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=20,b=10,l=20)),
        axis.title.y=element_text(face="bold",colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=10,b=10,l=10)),
        legend.position="none", 
        panel.background=element_rect(fill="white"),
        panel.border=element_rect(linewidth=1,linetype="solid",
                                  colour="black"),
        panel.grid.major=element_blank(),
        panel.grid.minor=element_blank())+
  geom_text(label="White mantis",
            x=0.7,y=0.38,size=3.5)+
  geom_text(label="ns",fontface="bold",
            x=1.5,y=0.3,size=3)

## Liturgusidae - Grey morph 

graph_lit2_gabrat_a<-
  ggplot(data=data_gabrat%>%
         filter(species=="lit2"))+
  geom_boxplot(aes(x=background,y=gabrat,fill=background),
               linewidth=0.5,alpha=0.25,outlier.shape=NA,
               show.legend=FALSE)+
  geom_jitter(aes(x=background,y=gabrat,fill=background),
              position=position_jitterdodge(),size=2.5,shape=21,
              show.legend=FALSE)

graph_lit2_gabrat_b<-
  graph_lit2_gabrat_a+
  scale_x_discrete(name="Background",
                   labels=c("Greenish-brown","Whitish"))+
  scale_y_continuous(name="GabRat",
                     breaks=c(0.05,0.1,0.15,0.2,0.25,0.3,0.35,0.4),
                     limits=c(0.05,0.4))+
  scale_fill_manual(values=c("#33FF00","#FFFFFF"))

graph_lit2_gabrat_c<-
  graph_lit2_gabrat_b+
  theme_bw()+
  theme(axis.text.x=element_text(colour="black",size=10,hjust=0.5),
        axis.text.y=element_text(colour="black",size=10),
        axis.title.x=element_text(face="bold", colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=20,b=10,l=20)),
        axis.title.y=element_text(face="bold",colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=10,b=10,l=10)),
        legend.position="none", 
        panel.background=element_rect(fill="white"),
        panel.border=element_rect(linewidth=1,linetype="solid",
                                  colour="black"),
        panel.grid.major=element_blank(),
        panel.grid.minor=element_blank())+
  geom_text(label="Grey mantis",
            x=0.7,y=0.38,size=3.5)+
  geom_text(label="ns",fontface="bold",
            x=1.5,y=0.325,size=3)

## Liturgusa - Green morph 

graph_lit1_gabrat_a<-
  ggplot(data=data_gabrat%>%
           filter(species=="lit1"))+
  geom_boxplot(aes(x=background,y=gabrat,fill=background),
               linewidth=0.5,alpha=0.25,outlier.shape=NA,
               show.legend=FALSE)+
  geom_jitter(aes(x=background,y=gabrat,fill=background),
              position=position_jitterdodge(),size=2.5,shape=21,
              show.legend=FALSE)

graph_lit1_gabrat_b<-
  graph_lit1_gabrat_a+
  scale_x_discrete(name="Background",
                   labels=c("Greenish-brown","Whitish"))+
  scale_y_continuous(name="GabRat",
                     breaks=c(0.05,0.1,0.15,0.2,0.25,0.3,0.35,0.4),
                     limits=c(0.05,0.4))+
  scale_fill_manual(values=c("#33FF00","#FFFFFF"))

graph_lit1_gabrat_c<-
  graph_lit1_gabrat_b+
  theme_bw()+
  theme(axis.text.x=element_text(colour="black",size=10,hjust=0.5),
        axis.text.y=element_text(colour="black",size=10),
        axis.title.x=element_text(face="bold", colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=20,b=10,l=20)),
        axis.title.y=element_text(face="bold",colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=10,b=10,l=10)),
        legend.position="none", 
        panel.background=element_rect(fill="white"),
        panel.border=element_rect(linewidth=1,linetype="solid",
                                  colour="black"),
        panel.grid.major=element_blank(),
        panel.grid.minor=element_blank())+
  geom_text(label="Green mantis",
            x=0.7,y=0.38,size=3.5)+
  geom_text(label="*",fontface="bold",
            x=1.5,y=0.325,size=5)

################################################################################
### Combining all plots

final_figure_gabrat<-
  graph_hagi_gabrat_c+
  graph_lit2_gabrat_c+
  graph_lit1_gabrat_c+
  plot_layout(ncol=1)

# Remove title and text for plots 1 and 2

final_figure_gabrat[[1]]<-
  final_figure_gabrat[[1]]+
  theme(plot.margin=margin(0.5,0.5,0,0.5,"cm"),
        axis.title.x=element_blank(),
        axis.text.x=element_blank())

final_figure_gabrat[[2]]<-
  final_figure_gabrat[[2]]+
  theme(plot.margin=margin(0.5,0.5,0,0.5,"cm"),
        axis.title.x=element_blank(),
        axis.text.x=element_blank())

final_figure_gabrat[[3]]<-
  final_figure_gabrat[[3]]+
  theme(plot.margin=margin(0.5,0.5,0.5,0.5,"cm"))

ggsave("Figure 4.png",final_figure_gabrat,
       height=25,width=17.5,units="cm",dpi=600)
