## Packages ##

library(tidyverse)
library(readxl)
library(ggpubr)
library(patchwork)
library(grid)
library(rstatix)
library(lme4)
library(lmerTest)
library(emmeans)
library(performance)
library(afex)

################################################################################
## Using raw data
################################################################################

predation_data_raw<-
  read_excel("predation_data.xlsx",
             sheet=2,range="A1:F253")%>%
  mutate(mantis=factor(mantis),
         background=factor(background))

## creating new model

## Searching time

predation_data_raw$log_search_time<-
  log10(predation_data_raw$search_time)

model_st<-
  lmer(log_search_time~background*mantis+(1|participant_id)+
      (1|tree_id),
      data=predation_data_raw)

check_model(model_st)
qqnorm(residuals(model_st))
qqline(residuals(model_st))

anova(model_st)

ranova(model_st)

summary(model_st)

pairs(emmeans(model_st,~mantis|background))

predation_data_raw%>%
  group_by(background,mantis)%>%
  summarise(mean_st=mean(search_time),
            sample_size=n(),
            sd_st=sd(search_time))%>%
  mutate(se_st=sd_st/sqrt(sample_size))

## Encounter distance

model_ed<-
  lmer(encounter_distance~background*mantis+(1|participant_id)+
       (1|tree_id),
       data=predation_data_raw)

check_model(model_ed)
qqnorm(residuals(model_ed))
qqline(residuals(model_ed))

anova(model_ed)

pairs(emmeans(model_ed,"background",by="mantis"))

predation_data_raw%>%
  group_by(background,mantis)%>%
  summarise(mean_ed=mean(encounter_distance),
            sample_size=n(),
            sd_ed=sd(encounter_distance))%>%
  mutate(se_ed=sd_ed/sqrt(sample_size))

## Afex plots

afex_plot_st<-
  afex_plot(model_st,x="mantis",panel="background",
            error_arg=list(linewidth=0.5,width=0.05),
            point_arg=list(size=6,shape=21,stroke=1,
                         fill=c("#33FF00","#FFFFFF","#33FF00","#FFFFFF"),
                         colour="black"),
            factor_levels=list(background=c("Greenish-brown trunks",
                                          "Whitish trunks"),
                             mantis=c("Green","White")),
            mapping=c("fill"),data_alpha=0.25,
            data_geom=ggplot2::geom_point,
            data_arg=
            list(size=2.5,
                 shape=21,
                 colour="black"))+
  labs(y="log [Search time (s)]",x="Mantis model")+
  scale_y_continuous(breaks=c(0,0.5,1,1.5,2,2.5),
                     limits=c(0,2.5))+
  scale_fill_manual(values=c("#33FF00","#FFFFFF"))+
  theme_bw()+
  theme(axis.text.x=element_text(colour="black",size=10,hjust=0.5),
        axis.text.y=element_text(colour="black",size=10),
        axis.title.x=element_text(face="bold", colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=20,b=10,l=20)),
        axis.title.y=element_text(face="bold",colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=10,b=10,l=10)),
        legend.position="none",
        panel.background=element_rect(fill="white"),
        panel.border=element_rect(linewidth=1,linetype="solid",
                                  colour="black"),
        panel.grid.major=element_blank(),
        panel.grid.minor=element_blank(),
        strip.text.x=element_text(size=12,face="bold"),
        strip.background=element_rect(colour="black"),
        panel.spacing=unit(0.5,"cm"))

afex_plot_st$data # see the model parameters that are plotted

afex_plot_ed<-
  afex_plot(model_ed,x="mantis",panel="background",
            error_arg=list(linewidth=0.5,width=0.05),
            point_arg=list(size=6,shape=21,stroke=1,
                           fill=c("#33FF00","#FFFFFF","#33FF00","#FFFFFF"),
                           colour="black"),
            factor_levels=list(background=c("Greenish-brown trunks",
                                            "Whitish trunks"),
                               mantis=c("Green","White")),
            mapping=c("fill"),data_alpha=0.25,
            data_geom=ggplot2::geom_point,
            data_arg=
              list(size=2.5,
                   shape=21,
                   colour="black"))+
  labs(y="Encounter distance (m)",x="Mantis model")+
  scale_y_continuous(breaks=c(0,2,4,6,8,10),
                     limits=c(0,10))+
  scale_fill_manual(values=c("#33FF00","#FFFFFF"))+
  theme_bw()+
  theme(axis.text.x=element_text(colour="black",size=10,hjust=0.5),
        axis.text.y=element_text(colour="black",size=10),
        axis.title.x=element_text(face="bold", colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=20,b=10,l=20)),
        axis.title.y=element_text(face="bold",colour="black", 
                                  size=12,margin=margin(
                                    t=10,r=10,b=10,l=10)),
        legend.position="none",
        panel.background=element_rect(fill="white"),
        panel.border=element_rect(linewidth=1,linetype="solid",
                                  colour="black"),
        panel.grid.major=element_blank(),
        panel.grid.minor=element_blank(),
        strip.text.x=element_text(size=12,face="bold"),
        strip.background=element_rect(colour="black"),
        panel.spacing=unit(0.5,"cm"))

afex_plot_ed$data # see the model parameters that are plotted

### Combining the two plots

final_figure_predation_afex<-
  afex_plot_st+
  afex_plot_ed+
  plot_layout(ncol=1)

# Remove title and text for plot 1 and facets for plot 2

final_figure_predation_afex[[1]]<-
  final_figure_predation_afex[[1]]+
  theme(plot.margin=margin(0.5,0.5,0,0.5,"cm"),
        axis.title.x=element_blank(),
        axis.text.x=element_blank())

final_figure_predation_afex[[2]]<-
  final_figure_predation_afex[[2]]+
  theme(plot.margin=margin(0.5,0.5,0.5,0.5,"cm"),
        strip.text.x=element_blank(),
        strip.background=element_blank())

ggsave("Figure 5 afex.png",final_figure_predation_afex,
       height=20,width=20,units="cm",dpi=600)

################################################################################
## pairing the response variables for each tree
################################################################################

## another way to remove the dependence between pairs located at the same
## tree

predation_paired_data<-
  predation_data_raw%>%
  group_by(participant_id,background,tree_id)%>%
  summarise(dif_st=diff(search_time)*(-1),
            dif_ed=diff(encounter_distance)*(-1))%>%
  filter(participant_id!=21)
  

model_st_paired<-
  lmer(dif_st~background+(1|participant_id),
       data=predation_paired_data)

qqnorm(residuals(model_st_paired))
qqline(residuals(model_st_paired))

anova(model_st_paired)

pairs(emmeans(model_st_paired,"background"))

ggplot(predation_paired_data)+
  geom_boxplot(aes(x=background,y=dif_st,fill=background))

